@@ -1,4 +1,4 @@
-"""test_Targets.py
+"""test_targets.py
 
 Tests for the Targets Plugin
 """
@@ -24,36 +24,36 @@ class TargetsTestCase(unittest.TestCase):
         self.targets.scratchspace = MagicMock()
         self.maxDiff = None
 
-    def test_get_assessments_all_passed(self):
-        """Should return a list of passed assessments"""
-        assessments = [
-            {
-                "category_name": "Cat1",
-                "category_id": "1",
-                "written_assessment": {
-                    "passed": True
-                },
-                "practical_assessment": {
-                    "passed": True
-                }
-            },
-            {
-                "category_name": "Cat2",
-                "category_id": "2",
-                "written_assessment": {
-                    "passed": True
-                },
-                "practical_assessment": {
-                    "passed": True
-                }
-            }
+    def test_build_codename_from_slug(self):
+        """Should return a codename for a given slug"""
+        ret_targets = [Target(codename="SLOPPYSLUG")]
+        self.targets.db.find_targets.return_value = ret_targets
+        self.assertEqual("SLOPPYSLUG",
+                         self.targets.build_codename_from_slug("qwfars"))
+        self.targets.db.find_targets.assert_called_with(slug="qwfars")
+
+    def test_build_codename_from_slug_invalid(self):
+        """Should return NONE if non-real slug"""
+        self.targets.db.find_targets.return_value = []
+        self.assertEqual("NONE",
+                         self.targets.build_codename_from_slug("qwfars"))
+        self.targets.db.find_targets.assert_called_with(slug="qwfars")
+
+    def test_build_codename_from_slug_no_targets(self):
+        """Should update the targets if empty"""
+        self.targets.db.find_targets.side_effect = [
+            [],
+            [Target(codename="SLOPPYSLUG")]
         ]
-        cat1 = synack.db.models.Category()
-        self.targets.api.request.return_value.status_code = 200
-        self.targets.api.request.return_value.json.return_value = assessments
-        self.targets.db.categories = [cat1]
-        self.assertEqual([cat1], self.targets.get_assessments())
-        self.targets.db.add_categories.assert_called_with(assessments)
+        calls = [
+            unittest.mock.call(slug="qwfars"),
+            unittest.mock.call(slug="qwfars")
+        ]
+        self.targets.get_registered_summary = MagicMock()
+        self.assertEqual("SLOPPYSLUG",
+                         self.targets.build_codename_from_slug("qwfars"))
+        self.targets.db.find_targets.assert_has_calls(calls)
+        self.targets.get_registered_summary.assert_called_with()
 
     def test_build_scope_host_db(self):
         """Should build a scope that can be ingested into the Database given a Synack API Scope"""
@@ -192,36 +192,36 @@ class TargetsTestCase(unittest.TestCase):
         self.targets.db.find_targets.assert_has_calls(calls)
         self.targets.get_registered_summary.assert_called_with()
 
-    def test_build_codename_from_slug(self):
-        """Should return a codename for a given slug"""
-        ret_targets = [Target(codename="SLOPPYSLUG")]
-        self.targets.db.find_targets.return_value = ret_targets
-        self.assertEqual("SLOPPYSLUG",
-                         self.targets.build_codename_from_slug("qwfars"))
-        self.targets.db.find_targets.assert_called_with(slug="qwfars")
-
-    def test_build_codename_from_slug_no_targets(self):
-        """Should update the targets if empty"""
-        self.targets.db.find_targets.side_effect = [
-            [],
-            [Target(codename="SLOPPYSLUG")]
+    def test_get_assessments_all_passed(self):
+        """Should return a list of passed assessments"""
+        assessments = [
+            {
+                "category_name": "Cat1",
+                "category_id": "1",
+                "written_assessment": {
+                    "passed": True
+                },
+                "practical_assessment": {
+                    "passed": True
+                }
+            },
+            {
+                "category_name": "Cat2",
+                "category_id": "2",
+                "written_assessment": {
+                    "passed": True
+                },
+                "practical_assessment": {
+                    "passed": True
+                }
+            }
         ]
-        calls = [
-            unittest.mock.call(slug="qwfars"),
-            unittest.mock.call(slug="qwfars")
-        ]
-        self.targets.get_registered_summary = MagicMock()
-        self.assertEqual("SLOPPYSLUG",
-                         self.targets.build_codename_from_slug("qwfars"))
-        self.targets.db.find_targets.assert_has_calls(calls)
-        self.targets.get_registered_summary.assert_called_with()
-
-    def test_build_codename_from_slug_invalid(self):
-        """Should return NONE if non-real slug"""
-        self.targets.db.find_targets.return_value = []
-        self.assertEqual("NONE",
-                         self.targets.build_codename_from_slug("qwfars"))
-        self.targets.db.find_targets.assert_called_with(slug="qwfars")
+        cat1 = synack.db.models.Category()
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.api.request.return_value.json.return_value = assessments
+        self.targets.db.categories = [cat1]
+        self.assertEqual([cat1], self.targets.get_assessments())
+        self.targets.db.add_categories.assert_called_with(assessments)
 
     def test_get_connected(self):
         """Should make a request to get the currently selected target"""
@@ -240,6 +240,23 @@ class TargetsTestCase(unittest.TestCase):
         }
         self.assertEqual(out, self.targets.get_connected())
 
+    def test_get_connected_disconnected(self):
+        """Should report Not Connected when not connected to a target"""
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.api.request.return_value.json.return_value = {
+            "pending_slug": "-1",
+            "slug": "",
+            "status": "connected"
+        }
+        self.targets.build_codename_from_slug = MagicMock()
+        self.targets.build_codename_from_slug.return_value = "NONE"
+        out = {
+            "slug": "",
+            "codename": "NONE",
+            "status": "Not Connected"
+        }
+        self.assertEqual(out, self.targets.get_connected())
+
     def test_get_connected_pending(self):
         """Should return the pending target if one is pending"""
         self.targets.api.request.return_value.status_code = 200
@@ -257,22 +274,45 @@ class TargetsTestCase(unittest.TestCase):
         }
         self.assertEqual(out, self.targets.get_connected())
 
-    def test_get_connected_disconnected(self):
-        """Should report Not Connected when not connected to a target"""
+    def test_get_credentials(self):
+        """Should get credentials for a given target"""
+        target = Target(organization="qwewqe", slug="asdasd")
+        self.targets.db.find_targets = MagicMock()
+        self.targets.api = MagicMock()
+        self.targets.db.find_targets.return_value = [target]
+        self.targets.db.user_id = 'bobby'
         self.targets.api.request.return_value.status_code = 200
-        self.targets.api.request.return_value.json.return_value = {
-            "pending_slug": "-1",
-            "slug": "",
-            "status": "connected"
+        self.targets.api.request.return_value.json.return_value = "json_return"
+
+        url = 'asset/v1/organizations/qwewqe/owners/listings/asdasd/users/bobby/credentials'
+
+        self.assertEqual("json_return",
+                         self.targets.get_credentials(codename='SLEEPYSLUG'))
+        self.targets.api.request.assert_called_with('POST', url)
+
+    def test_get_registered_summary(self):
+        """Should make a request to get basic info about registered targets"""
+        t1 = {
+            "id": "qwfars",
+            "codename": "SLOPPYSLUG",
+            "organization_id": "89yefds",
+            "activated_at": 1633640638,
+            "name": "Bob's Slug Hut",
+            "category": {
+                "id": 1,
+                "name": "Web Application"
+            },
+            "outage_windows": [],
+            "vulnerability_discovery": True
         }
-        self.targets.build_codename_from_slug = MagicMock()
-        self.targets.build_codename_from_slug.return_value = "NONE"
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.api.request.return_value.json.return_value = [t1]
         out = {
-            "slug": "",
-            "codename": "NONE",
-            "status": "Not Connected"
+            "qwfars": t1
         }
-        self.assertEqual(out, self.targets.get_connected())
+        path = 'targets/registered_summary'
+        self.assertEqual(out, self.targets.get_registered_summary())
+        self.targets.api.request.assert_called_with('GET', path)
 
     def test_get_scope_for_host(self):
         """Should get the scope for a Host when given Host information"""
@@ -312,6 +352,15 @@ class TargetsTestCase(unittest.TestCase):
         self.targets.api.request.assert_called_with('GET', 'targets/213h89h3/cidrs?page=all')
         self.targets.api.request.return_value.json.assert_called()
 
+    def test_get_scope_no_provided(self):
+        """Should get the scope for the currently connected target if none is specified"""
+        self.targets.get_connected = MagicMock()
+        self.targets.get_connected.return_value = {'slug': 'test'}
+        self.targets.db.find_targets.return_value = None
+        self.targets.get_scope()
+        self.targets.get_connected.assert_called_with()
+        self.targets.db.find_targets.assert_called_with(slug='test')
+
     def test_get_scope_web(self):
         """Should get the scope for a Web Application"""
         self.targets.api.request.return_value.status_code = 200
@@ -333,46 +382,6 @@ class TargetsTestCase(unittest.TestCase):
                                                     'asset/v1/organizations/93g8eh8/owners/listings/213h89h3/webapps')
         self.targets.api.request.return_value.json.assert_called()
 
-    def test_get_registered_summary(self):
-        """Should make a request to get basic info about registered targets"""
-        t1 = {
-            "id": "qwfars",
-            "codename": "SLOPPYSLUG",
-            "organization_id": "89yefds",
-            "activated_at": 1633640638,
-            "name": "Bob's Slug Hut",
-            "category": {
-                "id": 1,
-                "name": "Web Application"
-            },
-            "outage_windows": [],
-            "vulnerability_discovery": True
-        }
-        self.targets.api.request.return_value.status_code = 200
-        self.targets.api.request.return_value.json.return_value = [t1]
-        out = {
-            "qwfars": t1
-        }
-        path = 'targets/registered_summary'
-        self.assertEqual(out, self.targets.get_registered_summary())
-        self.targets.api.request.assert_called_with('GET', path)
-
-    def test_get_credentials(self):
-        """Should get credentials for a given target"""
-        target = Target(organization="qwewqe", slug="asdasd")
-        self.targets.db.find_targets = MagicMock()
-        self.targets.api = MagicMock()
-        self.targets.db.find_targets.return_value = [target]
-        self.targets.db.user_id = 'bobby'
-        self.targets.api.request.return_value.status_code = 200
-        self.targets.api.request.return_value.json.return_value = "json_return"
-
-        url = 'asset/v1/organizations/qwewqe/owners/listings/asdasd/users/bobby/credentials'
-
-        self.assertEqual("json_return",
-                         self.targets.get_credentials(codename='SLEEPYSLUG'))
-        self.targets.api.request.assert_called_with('POST', url)
-
     def test_get_unregistered(self):
         """Should get a list unregistered targets"""
         self.targets.db.categories = [
@@ -429,6 +438,16 @@ class TargetsTestCase(unittest.TestCase):
                                                     data={'listing_id': '28h93iw'})
         self.targets.get_connected.assert_called_with()
 
+    def test_set_connected_disconnect(self):
+        """Should disconnect from target if none specified"""
+        self.targets.api.request.return_value.status_code = 200
+        self.targets.get_connected = MagicMock()
+        self.targets.set_connected()
+        self.targets.api.request.assert_called_with('PUT',
+                                                    'launchpoint',
+                                                    data={'listing_id': ''})
+        self.targets.get_connected.assert_called_with()
+
     def test_set_connected_target(self):
         """Should connect to a given target provided a target"""
         target = Target(slug='28h93iw')
@@ -440,16 +459,6 @@ class TargetsTestCase(unittest.TestCase):
                                                     data={'listing_id': '28h93iw'})
         self.targets.get_connected.assert_called_with()
 
-    def test_set_connected_disconnect(self):
-        """Should disconnect from target if none specified"""
-        self.targets.api.request.return_value.status_code = 200
-        self.targets.get_connected = MagicMock()
-        self.targets.set_connected()
-        self.targets.api.request.assert_called_with('PUT',
-                                                    'launchpoint',
-                                                    data={'listing_id': ''})
-        self.targets.get_connected.assert_called_with()
-
     def test_set_registered(self):
         """Should register each unregistered target"""
         self.targets.get_unregistered = MagicMock()
